class Endpoints:
    base_url = "https://api.heytextual.com"
    extract = f"{base_url}/extract"
    documents = f"{base_url}/documents"
    document = f"{base_url}/api/documents"
    templates = f"{base_url}/templates"
